@@ -374,7 +374,7 @@ class Parameters(UserList):
 
         for choice in choices:
             template_array[chain_pars] = chains[..., choice]
-            yield template_array
+            yield np.asarray(template_array).astype(float, copy=False)
 
 
 class BaseParameter:
@@ -594,7 +594,7 @@ def sequence_to_parameters(seq):
 
     Returns
     -------
-    params: `refnx.analysis.Parameters
+    params: `refnx.analysis.Parameters`
     """
     flat_seq = flatten(seq)
     pars = [possibly_create_parameter(p) for p in flat_seq]
