@@ -1,4 +1,4 @@
-import os.path
+from pathlib import Path
 import pickle
 import sys
 
@@ -30,8 +30,9 @@ from refnx.analysis import (
 from refnx.analysis.curvefitter import bounds_list
 from refnx.dataset import Data1D
 from refnx._lib import emcee, flatten
+from refnx._lib.emcee.moves import DEMove, DESnookerMove
 
-from NISTModels import NIST_runner, NIST_Models
+from .NISTModels import NIST_runner, NIST_Models
 
 
 def line(x, params, *args, **kwds):
@@ -210,6 +211,14 @@ class TestCurveFitter:
         self.mcfitter.make_sampler()
         self.mcfitter.sample(1)
 
+    def test_moves(self):
+        # check that we can provide non-default moves
+        m0 = DEMove()
+        m1 = DESnookerMove()
+        moves = [(m0, 0.8), (m1, 0.2)]
+        mcfitter = CurveFitter(self.objective, moves=moves)
+        mcfitter.sample(10)
+
     def test_random_seed(self):
         # check that MCMC sampling is reproducible
         self.mcfitter.sample(steps=2, random_state=1)
@@ -399,11 +408,11 @@ class TestFitterGauss:
     # if the parameters and uncertainties come out correct
 
     @pytest.fixture(autouse=True)
-    def setup_method(self, tmpdir):
-        self.path = os.path.dirname(os.path.abspath(__file__))
-        self.tmpdir = tmpdir.strpath
+    def setup_method(self, tmp_path):
+        self.path = Path(__file__).absolute().parent
+        self.tmp_path = tmp_path
 
-        theoretical = np.loadtxt(os.path.join(self.path, "gauss_data.txt"))
+        theoretical = np.loadtxt(self.path / "gauss_data.txt")
         xvals, yvals, evals = np.hsplit(theoretical, 3)
         xvals = xvals.flatten()
         yvals = yvals.flatten()
@@ -482,7 +491,7 @@ class TestFitterGauss:
         assert_allclose(uncertainties, self.best_weighted_errors, rtol=0.005)
 
         # we're also going to try the checkpointing here.
-        checkpoint = os.path.join(self.tmpdir, "checkpoint.txt")
+        checkpoint = self.tmp_path / "checkpoint.txt"
 
         # compare samples to best_weighted_errors
         np.random.seed(1)
@@ -626,7 +635,8 @@ class TestFitterGauss:
 
     @pytest.mark.xfail(
         sys.platform == "win32"
-        and (sys.version_info.major, sys.version_info.minor) == (3, 8),
+        and (sys.version_info.major, sys.version_info.minor)
+        in [(3, 8), (3, 9), (3, 10)],
         run=False,
         reason="doesn't work on cp38",
     )
