@@ -1,9 +1,9 @@
 """"
 A basic representation of a 1D dataset
 """
-import os.path
 from pathlib import Path, PurePath
 import re
+import io
 
 import numpy as np
 from scipy._lib._util import check_random_state
@@ -111,7 +111,7 @@ class Data1D:
         if np.all(self._mask):
             msk = None
 
-        d = {"filename": self.filename, "msk": msk, "data": self.data}
+        d = {"filename": str(self.filename), "msk": msk, "data": self.data}
         if self.filename is not None:
             return "Data1D(data={filename!r}," " mask={msk!r})".format(**d)
         else:
@@ -478,13 +478,18 @@ class Data1D:
 
         self.data = (x, y, y_err, x_err)
 
-        if hasattr(f, "read"):
-            fname = f.name
+        if hasattr(f, "read") and hasattr(f, "write"):
+            if hasattr(f, "name"):
+                # file-like ?
+                fname = f.name
+            else:
+                # BytesIO/ StringIO?
+                fname = ""
         else:
             fname = f
 
         self.filename = fname
-        self.name = os.path.splitext(os.path.basename(fname))[0]
+        self.name = Path(fname).stem
 
     def refresh(self):
         """
@@ -591,3 +596,54 @@ class Data1D:
         dataset.data = data
 
         return dataset
+
+
+def _data1D_to_hdf(fname, data):
+    """
+    Writes a Data1D object to rudimentary HDF.
+
+    Parameters
+    ----------
+    fname: str, BytesIO
+        Filename to write to
+
+    data: Data1D
+        dataset to write to file
+    """
+    import h5py
+
+    with h5py.File(fname, "w") as f:
+        f.create_group("entry1/data")
+        for attr in ["x", "y", "y_err", "x_err"]:
+            v = getattr(data, attr)
+            if v is not None:
+                f.create_dataset(f"entry1/data/{attr}", data=v)
+
+
+def _hdf_to_data1d(fname):
+    """
+    Reads a rudimentary HDF file into a Data1D object.
+
+    Parameters
+    ----------
+    fname: str, BytesIO
+        File to read from
+
+    Returns
+    -------
+    data: Data1D
+        dataset read from file
+    """
+    import h5py
+
+    d = []
+    with h5py.File(fname, "r") as f:
+        for attr in ["x", "y", "y_err", "x_err"]:
+            try:
+                d.append(f[f"entry1/data/{attr}"][:])
+            except KeyError:
+                pass
+
+    data = Data1D(data=d)
+    data.filename = fname
+    return data
