@@ -1,5 +1,4 @@
-import os.path
-
+from pathlib import Path
 from qtpy import QtCore, QtWidgets, uic
 import numpy as np
 
@@ -20,7 +19,7 @@ import refnx.reduce._app as floc
 matplotlib.use("QtAgg")
 
 
-UI_LOCATION = os.path.join(os.path.dirname(floc.__file__), "ui")
+UI_LOCATION = Path(floc.__file__).parent / "ui"
 
 
 class ManualBeamFinder(QtWidgets.QDialog):
@@ -35,9 +34,7 @@ class ManualBeamFinder(QtWidgets.QDialog):
     def __init__(self, parent=None):
         """ """
         super().__init__()
-        self.dialog = uic.loadUi(
-            os.path.join(UI_LOCATION, "manual_beam.ui"), self
-        )
+        self.dialog = uic.loadUi(UI_LOCATION / "manual_beam.ui", self)
 
         # values for spinboxes
         self._true_centre = 500.0
@@ -121,7 +118,9 @@ class ManualBeamFinder(QtWidgets.QDialog):
         # guess peak centre from centroid.
         xs = np.sum(self.detector, axis=0)
         self._integrate_position, _ = centroid(xs)
-        self.integrate_position.setValue(self._integrate_position)
+        self.integrate_position.setValue(
+            int(np.round(self._integrate_position))
+        )
         self.integrate_width.setValue(self._integrate_width)
 
         self.recalculate_graphs()
@@ -609,7 +608,7 @@ class Cross_Section(FigureCanvas):
             attr, line = found
             dx = x - xpress
             # dy = y - ypress
-            new_loc = int(round(loc + dx))
+            new_loc = int(np.round(loc + dx))
 
             # TODO make sure lopx and high px cant cross
             # TODO recalc backgrounds and beam centre after plot_button release
