@@ -1,5 +1,4 @@
 import os
-from os.path import join as pjoin
 import numbers
 import warnings
 import pickle
@@ -9,7 +8,6 @@ import pytest
 import numpy as np
 from numpy.testing import (
     assert_almost_equal,
-    assert_,
     assert_equal,
     assert_array_less,
     assert_allclose,
@@ -34,17 +32,19 @@ from refnx.reduce.platypusnexus import (
     create_detector_norm,
     Catalogue,
     PlatypusCatalogue,
+    create_reflect_nexus,
+    ReductionOptions,
 )
 
 
 class TestSpinSet(object):
     @pytest.mark.usefixtures("no_data_directory")
     @pytest.fixture(autouse=True)
-    def setup_method(self, tmpdir, data_directory):
-        self.pth = pjoin(data_directory, "reduce", "PNR_files")
+    def setup_method(self, tmp_path, data_directory):
+        self.pth = data_directory / "reduce" / "PNR_files"
 
         def fpath(f):
-            return pjoin(self.pth, f)
+            return self.pth / f
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", RuntimeWarning)
@@ -66,10 +66,10 @@ class TestSpinSet(object):
                 up_up=fpath("PLP0008861.nx.hdf"),
             )
 
-        self.cwd = os.getcwd()
+        self.cwd = Path.cwd()
 
-        self.tmpdir = tmpdir.strpath
-        os.chdir(self.tmpdir)
+        self.tmp_path = tmp_path
+        os.chdir(self.tmp_path)
         return 0
 
     def test_spin_channels(self):
@@ -126,35 +126,35 @@ class TestSpinSet(object):
 class TestPlatypusNexus(object):
     @pytest.mark.usefixtures("no_data_directory")
     @pytest.fixture(autouse=True)
-    def setup_method(self, tmpdir, data_directory):
-        self.pth = pjoin(data_directory, "reduce")
+    def setup_method(self, tmp_path, data_directory):
+        self.pth = data_directory / "reduce"
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", RuntimeWarning)
-            self.f113 = PlatypusNexus(pjoin(self.pth, "PLP0011613.nx.hdf"))
+            self.f113 = PlatypusNexus(self.pth / "PLP0011613.nx.hdf")
 
             # to ensure that file can be opened with a Path
-            pth = Path(self.pth) / "PLP0011641.nx.hdf"
+            pth = self.pth / "PLP0011641.nx.hdf"
             self.f641 = PlatypusNexus(pth)
 
             # These PNR datasets all have different flipper settings
             self.f8861 = PlatypusNexus(
-                pjoin(self.pth, "PNR_files/PLP0008861.nx.hdf")
+                self.pth / "PNR_files/PLP0008861.nx.hdf"
             )
             self.f8862 = PlatypusNexus(
-                pjoin(self.pth, "PNR_files/PLP0008862.nx.hdf")
+                self.pth / "PNR_files/PLP0008862.nx.hdf"
             )
             self.f8863 = PlatypusNexus(
-                pjoin(self.pth, "PNR_files/PLP0008863.nx.hdf")
+                self.pth / "PNR_files/PLP0008863.nx.hdf"
             )
             self.f8864 = PlatypusNexus(
-                pjoin(self.pth, "PNR_files/PLP0008864.nx.hdf")
+                self.pth / "PNR_files/PLP0008864.nx.hdf"
             )
 
-        self.cwd = os.getcwd()
+        self.cwd = Path.cwd()
 
-        self.tmpdir = tmpdir.strpath
-        os.chdir(self.tmpdir)
+        self.tmp_path = tmp_path
+        os.chdir(self.tmp_path)
         return 0
 
     def teardown_method(self):
@@ -198,7 +198,7 @@ class TestPlatypusNexus(object):
             yvals, yvals_sd, mask
         )
 
-        verified_data = np.load(pjoin(self.pth, "background_subtract.npy"))
+        verified_data = np.load(self.pth / "background_subtract.npy")
 
         assert_almost_equal(verified_data, np.c_[profile, profile_sd])
 
@@ -210,7 +210,7 @@ class TestPlatypusNexus(object):
         output = plp.find_specular_ridge(
             detector[np.newaxis, :], detector_sd[np.newaxis, :]
         )
-        assert_(len(output) == 5)
+        assert len(output) == 5
         assert_almost_equal(output[0][0], 100)
 
     def test_pickle(self):
@@ -250,7 +250,7 @@ class TestPlatypusNexus(object):
 
         # each of the (N, T) entries should have the same background subtracted
         # entries
-        verified_data = np.load(pjoin(self.pth, "background_subtract.npy"))
+        verified_data = np.load(self.pth / "background_subtract.npy")
 
         it = np.nditer(detector, flags=["multi_index"])
         it.remove_axis(2)
@@ -269,7 +269,7 @@ class TestPlatypusNexus(object):
         # When you use event mode processing, make sure the right amount of
         # spectra are created
         out = self.f641.process(eventmode=[0, 900, 1800], integrate=0)
-        assert_(np.size(out[1], axis=0) == 2)
+        assert np.size(out[1], axis=0) == 2
 
     def test_event_folder(self):
         self.f641.process(
@@ -313,23 +313,23 @@ class TestPlatypusNexus(object):
         self.f113.process()
 
         # can save the spectra by supplying a filename
-        self.f113.write_spectrum_xml(pjoin(self.tmpdir, "test.xml"))
-        self.f113.write_spectrum_dat(pjoin(self.tmpdir, "test.dat"))
+        self.f113.write_spectrum_xml(self.tmp_path / "test.xml")
+        self.f113.write_spectrum_dat(self.tmp_path / "test.dat")
 
         # can save by supplying file handle:
-        with open(pjoin(self.tmpdir, "test.xml"), "wb") as f:
+        with open(self.tmp_path / "test.xml", "wb") as f:
             self.f113.write_spectrum_xml(f)
 
     def test_accumulate_files(self):
         fnames = ["PLP0000708.nx.hdf", "PLP0000709.nx.hdf"]
-        pths = [pjoin(self.pth, fname) for fname in fnames]
+        pths = [self.pth / fname for fname in fnames]
         plp.accumulate_HDF_files(pths)
         f8, f9, fadd = None, None, None
 
         try:
-            f8 = h5py.File(pjoin(self.pth, "PLP0000708.nx.hdf"), "r")
-            f9 = h5py.File(pjoin(self.pth, "PLP0000709.nx.hdf"), "r")
-            fadd = h5py.File(pjoin(self.tmpdir, "ADD_PLP0000708.nx.hdf"), "r")
+            f8 = h5py.File(self.pth / "PLP0000708.nx.hdf", "r")
+            f9 = h5py.File(self.pth / "PLP0000709.nx.hdf", "r")
+            fadd = h5py.File(self.tmp_path / "ADD_PLP0000708.nx.hdf", "r")
 
             f8d = f8["entry1/data/hmm"][0]
             f9d = f9["entry1/data/hmm"][0]
@@ -346,29 +346,29 @@ class TestPlatypusNexus(object):
     def test_accumulate_files_reduce(self):
         # test by adding a file to itself. Should have smaller stats
         fnames = ["PLP0000708.nx.hdf", "PLP0000708.nx.hdf"]
-        pths = [pjoin(self.pth, fname) for fname in fnames]
+        pths = [self.pth / fname for fname in fnames]
         plp.accumulate_HDF_files(pths)
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", RuntimeWarning)
             # it should be processable
-            fadd = PlatypusNexus(pjoin(os.getcwd(), "ADD_PLP0000708.nx.hdf"))
+            fadd = PlatypusNexus(Path.cwd() / "ADD_PLP0000708.nx.hdf")
             fadd.process()
 
             # it should also be reduceable
-            reducer = PlatypusReduce(pjoin(self.pth, "PLP0000711.nx.hdf"))
+            reducer = PlatypusReduce(self.pth / "PLP0000711.nx.hdf")
 
             datasets, reduced = reducer.reduce(
-                pjoin(os.getcwd(), "ADD_PLP0000708.nx.hdf")
+                Path.cwd() / "ADD_PLP0000708.nx.hdf"
             )
-            assert_("y" in reduced)
+            assert "y" in reduced
 
             # the error bars should be smaller
             datasets2, reduced2 = reducer.reduce(
-                pjoin(self.pth, "PLP0000708.nx.hdf")
+                self.pth / "PLP0000708.nx.hdf"
             )
 
-            assert_(np.all(reduced["y_err"] < reduced2["y_err"]))
+            assert np.all(reduced["y_err"] < reduced2["y_err"])
 
     def test_manual_beam_find(self):
         # you can specify a function that finds where the specular ridge is.
@@ -380,10 +380,10 @@ class TestPlatypusNexus(object):
             return beam_centre, beam_sd, np.array([40]), np.array([60]), [[]]
 
         # the manual beam find is only mandatory when peak_pos == -1.
-        # the beam_sd is much larger than the beam divergence, so a warning
-        # should be raised.
-        with pytest.warns(UserWarning):
-            self.f113.process(manual_beam_find=manual_beam_find, peak_pos=-1)
+        # # the beam_sd is much larger than the beam divergence, so a warning
+        # # should be raised.
+        # with pytest.warns(UserWarning):
+        self.f113.process(manual_beam_find=manual_beam_find, peak_pos=-1)
         assert_equal(self.f113.processed_spectrum["m_beampos"][0], 50)
 
         # manual beam finding also specifies the lower and upper pixel of the
@@ -397,11 +397,11 @@ class TestPlatypusNexus(object):
         sd = np.array([5.0, 11.5])
         lopx, hipx, background_pixels = fore_back_region(centres, sd)
 
-        assert_(len(lopx) == 2)
-        assert_(len(hipx) == 2)
-        assert_(len(background_pixels) == 2)
-        assert_(isinstance(lopx[0], numbers.Integral))
-        assert_(isinstance(hipx[0], numbers.Integral))
+        assert len(lopx) == 2
+        assert len(hipx) == 2
+        assert len(background_pixels) == 2
+        assert isinstance(lopx[0], numbers.Integral)
+        assert isinstance(hipx[0], numbers.Integral)
 
         calc_lower = np.floor(centres - sd * EXTENT_MULT)
         assert_equal(lopx, calc_lower)
@@ -422,13 +422,27 @@ class TestPlatypusNexus(object):
 
         assert_equal(bp, background_pixels[0])
 
+    def test_lopx_hipx(self):
+        # we should be able to specify the exact pixel numbers we want to
+        # integrate
+        rdo = ReductionOptions(
+            lopx_hipx=(50, 60), background=False, peak_pos=(55, 2)
+        )
+        _, m_spec, _ = self.f113.process(**rdo)
+
+        m_topandtail = self.f113.m_topandtail
+        assert self.f113.lopx[0] == 50
+        assert self.f113.hipx[0] == 60
+        check = np.sum(m_topandtail[..., 50:61], axis=-1)[0]
+        assert_allclose(m_spec[0], check)
+
     def test_basename_datafile(self):
         # check that the right basename is returned
         pth = "a/b/c.nx.hdf"
-        assert_(basename_datafile(pth) == "c")
+        assert basename_datafile(pth) == "c"
 
         pth = "c.nx.hdf"
-        assert_(basename_datafile(pth) == "c")
+        assert basename_datafile(pth) == "c"
 
     def test_floodfield_correction(self):
         # check that flood field calculation works
@@ -441,7 +455,7 @@ class TestPlatypusNexus(object):
             [0.05600541, 0.05879208, 0.04902215, 0.04425413, 0.05487956]
         )
 
-        fname = os.path.join(self.pth, "flood.h5")
+        fname = self.pth / "flood.h5"
         with h5py.File(fname, "r") as f:
             norm, norm_sd = create_detector_norm(f, 3.5, -3.5, axis=3)
 
@@ -484,9 +498,9 @@ class TestPlatypusNexus(object):
 
         # test spin channel setting
         # non spin analysed. mode is POL, not POLANAL
-        pn = PlatypusNexus(pjoin(self.pth, "PLP0016427.nx.hdf"))
+        pn = PlatypusNexus(self.pth / "PLP0016427.nx.hdf")
         assert pn.spin_state == SpinChannel.UP_UP
-        pn = PlatypusNexus(pjoin(self.pth, "PLP0016426.nx.hdf"))
+        pn = PlatypusNexus(self.pth / "PLP0016426.nx.hdf")
         assert pn.spin_state == SpinChannel.DOWN_DOWN
 
     def test_PNR_magnet_read(self):
@@ -499,17 +513,17 @@ class TestPlatypusNexus(object):
 class TestSpatzNexus:
     @pytest.mark.usefixtures("no_data_directory")
     @pytest.fixture(autouse=True)
-    def setup_method(self, tmpdir, data_directory):
-        self.pth = pjoin(data_directory, "reduce")
+    def setup_method(self, tmp_path, data_directory):
+        self.pth = data_directory / "reduce"
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", RuntimeWarning)
-            pth = Path(self.pth) / "SPZ0000342.nx.hdf"
+            pth = self.pth / "SPZ0000342.nx.hdf"
             self.f342 = SpatzNexus(pth)
-        self.cwd = os.getcwd()
+        self.cwd = Path.cwd()
 
-        self.tmpdir = tmpdir.strpath
-        os.chdir(self.tmpdir)
+        self.tmp_path = tmp_path
+        os.chdir(self.tmp_path)
         return 0
 
     def teardown_method(self):
@@ -549,21 +563,31 @@ class TestSpatzNexus:
         )
         assert_allclose(toff, 0, atol=1e-12)
 
+    def test_detector_translation(self):
+        f = SpatzNexus(self.pth / "SPZ0012268.nx.hdf")
+        dy = f.cat.cat["dy"]
+        assert_allclose(dy, 864.0137)
+
 
 @pytest.mark.usefixtures("no_data_directory")
 def test_catalogue(data_directory):
-    pth = pjoin(data_directory, "reduce")
+    pth = Path(data_directory) / "reduce"
     catalogue(0, 10000000, data_folder=pth, prefix="PLP")
     catalogue(0, 10000000, data_folder=pth, prefix="SPZ")
 
     pth = Path(data_directory) / "reduce"
     catalogue(0, 10000000, data_folder=pth, prefix="PLP")
 
+    # check that you can supply a sequence of keys to return
+    df = catalogue(0, 1000000, data_folder=pth, keys=["omega"])
+    assert df.columns.size == 1
+    assert df.columns[0] == "omega"
+
 
 @pytest.mark.usefixtures("no_data_directory")
 def test_Catalogue_pickle(data_directory):
-    pth = pjoin(data_directory, "reduce")
-    f113 = pjoin(pth, "PLP0011613.nx.hdf")
+    pth = Path(data_directory) / "reduce"
+    f113 = pth / "PLP0011613.nx.hdf"
     with h5py.File(f113) as f:
         c = PlatypusCatalogue(f)
 
@@ -571,3 +595,11 @@ def test_Catalogue_pickle(data_directory):
     assert c.prefix == "PLP"
     pkl = pickle.dumps(c)
     pickle.loads(pkl)
+
+
+@pytest.mark.usefixtures("no_data_directory")
+def test_create_nexus(data_directory):
+    pth = Path(data_directory) / "reduce"
+    f113 = pth / "PLP0011613.nx.hdf"
+    f = create_reflect_nexus(f113)
+    assert isinstance(f, PlatypusNexus)
