@@ -23,7 +23,7 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THIS SOFTWARE.
 
 """
-import os.path
+from pathlib import Path
 import numpy as np
 import numpy.typing as npt
 from typing import Optional
@@ -112,12 +112,12 @@ class _Abeles_pyopencl:
 
         if self.ctx is None or self.prg is None:
             self.ctx = cl.create_some_context(interactive=False)
-            pth = os.path.dirname(os.path.abspath(__file__))
-            with open(os.path.join(pth, "abeles_pyopencl.cl"), "r") as f:
+            pth = Path(__file__).absolute().parent
+            with open(pth / "abeles_pyopencl.cl", "r") as f:
                 src = f.read()
             self.prg = cl.Program(self.ctx, src).build()
 
-        qvals = np.asfarray(q)
+        qvals = np.asarray(q).astype(float)
         flatq = qvals.ravel()
 
         nlayers = len(w) - 2
@@ -195,7 +195,7 @@ def abeles(
     Reflectivity: np.ndarray
         Calculated reflectivity values for each q value.
     """
-    qvals = np.asfarray(q)
+    qvals = np.asarray(q).astype(float, copy=False)
     flatq = qvals.ravel()
 
     nlayers = layers.shape[0] - 2
@@ -298,7 +298,7 @@ def parratt(
     Reflectivity: np.ndarray
         Calculated reflectivity values for each q value.
     """
-    qvals = np.asfarray(q)
+    qvals = np.asarray(q).astype(float, copy=False)
     flatq = qvals.ravel()
 
     nlayers = layers.shape[0] - 2
@@ -621,7 +621,7 @@ def pnr(q, layers):
          probe of magnetic films and multilayers', Phys. Rev. B, (1992), 46,
          3391.
     """
-    xx = np.asfarray(q).astype(np.complex128).ravel()
+    xx = np.asarray(q).astype(np.complex128).ravel()
 
     thetas = np.radians(layers[:, 4])
     thetas = np.diff(thetas)
